PyXMake Developer Guide: PyXMake.__setenv__ Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Variables
PyXMake.__setenv__ Namespace Reference

Initialize PyXMake environment for Python scripts executed directly from the command line. More...

## Variables
| path
| key
| p = subprocess.Popen(__pyx_delimn.join([os.getenv("pyx_python_exe",sys.executable),__pyx_args]).split())
| _

## Detailed Description

Initialize PyXMake environment for Python scripts executed directly from the command line.

    Set up environment for PyXMake when executing scripts directly from command line.

    @note: PyXMake environment file.
    Created on 22.08.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  22.08.2020

Notes/Changes
  - Added documentation // mg 22.08.2020

## Variable Documentation

## ◆ _

PyXMake.__setenv__._
| protected

Definition at line 67 of file __setenv__.py.

## ◆ key

PyXMake.__setenv__.key

Definition at line 54 of file __setenv__.py.

## ◆ p

PyXMake.__setenv__.p = subprocess.Popen(__pyx_delimn.join([os.getenv("pyx_python_exe",sys.executable),__pyx_args]).split())

Definition at line 66 of file __setenv__.py.

## ◆ path

PyXMake.__setenv__.path

Definition at line 54 of file __setenv__.py.